on_popup_close_requested

Function on_popup_close_requested 

pub fn on_popup_close_requested(
    child: impl IntoUiNode,
    handler: Handler<PopupCloseRequestedArgs>,
) -> UiNode
P Closing popup event.

Requesting propagation().stop() on this event cancels the popup close.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.