pub struct PopupCloseRequestedArgs {
pub timestamp: DInstant,
pub popup: WidgetPath,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for POPUP_CLOSE_REQUESTED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
popup: WidgetPathThe popup that has close requested.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl PopupCloseRequestedArgs
impl PopupCloseRequestedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
popup: impl Into<WidgetPath>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, popup: impl Into<WidgetPath>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(popup: impl Into<WidgetPath>) -> Self
pub fn now(popup: impl Into<WidgetPath>) -> Self
Arguments for event that happened now (INSTANT.now).